@@ -40,7 +40,7 @@ from data.views.views import video_streams
 # Additionally, we include login URLs for the browsable API.
 urlpatterns = [
     path('', include(router.urls)),
-    url(r'^login/$', LoginView, name='login'),
+    url(r'^login/$', LoginView.as_view(template_name="registration/login.html"), name="login"),
     path('api-auth/', include('rest_framework.urls', namespace='rest_framework')),
     # path('start', views.start, name='start'),
     # path('calibrate', views.start, name='calibrate'),
